==> ejc-riskmortgage-impl-3.0.0-20231122.083741-80-sources.jar: com/ejianc/business/cash/bean/CashEntity.java <==
package com.ejianc.business.cash.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 兑现计算表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_riskmortgage_cash")
public class CashEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_org_id")
    private Long projectOrgId; // 项目所属组织id
    @TableField(value="project_org_code")
    private String projectOrgCode; // 项目所属组织编码
    @TableField(value="project_org_name")
    private String projectOrgName; // 项目所属组织名称
    @TableField(value="employee_id")
    private Long employeeId; // 经办人id
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办人部门id
    @TableField(value="department_code")
    private String departmentCode; // 经办人部门编码
    @TableField(value="department_name")
    private String departmentName; // 经办人部门名称
    @TableField(value="node_stage")
    private String nodeStage; // 节点阶段
    @TableField(value="approve_cost_mny")
    private BigDecimal approveCostMny; // 审定造价
    @TableField(value="pay_engineering_mny")
    private BigDecimal payEngineeringMny; // 已收工程款
    @TableField(value="cost_mny")
    private BigDecimal costMny; // 已归集实际成本
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 应缴税金
    @TableField(value="pay_tax_mny")
    private BigDecimal payTaxMny; // 已交税金
    @TableField(value="management_mny")
    private BigDecimal managementMny; // 应交管理费
    @TableField(value="pay_management_mny")
    private BigDecimal payManagementMny; // 已缴管理费
    @TableField(value="project_phase_mny")
    private BigDecimal projectPhaseMny; // 项目盈亏金额
    @TableField(value="corp_profit_mny")
    private BigDecimal corpProfitMny; // 应交公司利润
    @TableField(value="pay_corp_profit_mny")
    private BigDecimal payCorpProfitMny; // 已缴公司利润
    @TableField(value="project_cash_mny")
    private BigDecimal projectCashMny; // 项目应兑现金额
    @TableField(value="pay_project_cash_mny")
    private BigDecimal payProjectCashMny; // 已预支兑现
    @TableField(value="deduction_mny")
    private BigDecimal deductionMny; // 未完成责任指标扣款
    @TableField(value="risk_deduction_mny")
    private BigDecimal riskDeductionMny; // 风险金抵扣
    @TableField(value="examine_cash_mny")
    private BigDecimal examineCashMny; // 考核兑现金额
    @TableField(value="memo")
    private String memo; // 备注

    @TableField(value="bill_code")
    private String billCode; // 单据编码

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getProjectOrgId() {
        return projectOrgId;
    }

    public void setProjectOrgId(Long projectOrgId) {
        this.projectOrgId = projectOrgId;
    }
    public String getProjectOrgCode() {
        return projectOrgCode;
    }

    public void setProjectOrgCode(String projectOrgCode) {
        this.projectOrgCode = projectOrgCode;
    }
    public String getProjectOrgName() {
        return projectOrgName;
    }

    public void setProjectOrgName(String projectOrgName) {
        this.projectOrgName = projectOrgName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getNodeStage() {
        return nodeStage;
    }

    public void setNodeStage(String nodeStage) {
        this.nodeStage = nodeStage;
    }
    public BigDecimal getApproveCostMny() {
        return approveCostMny;
    }

    public void setApproveCostMny(BigDecimal approveCostMny) {
        this.approveCostMny = approveCostMny;
    }
    public BigDecimal getPayEngineeringMny() {
        return payEngineeringMny;
    }

    public void setPayEngineeringMny(BigDecimal payEngineeringMny) {
        this.payEngineeringMny = payEngineeringMny;
    }
    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getPayTaxMny() {
        return payTaxMny;
    }

    public void setPayTaxMny(BigDecimal payTaxMny) {
        this.payTaxMny = payTaxMny;
    }
    public BigDecimal getManagementMny() {
        return managementMny;
    }

    public void setManagementMny(BigDecimal managementMny) {
        this.managementMny = managementMny;
    }
    public BigDecimal getPayManagementMny() {
        return payManagementMny;
    }

    public void setPayManagementMny(BigDecimal payManagementMny) {
        this.payManagementMny = payManagementMny;
    }
    public BigDecimal getProjectPhaseMny() {
        return projectPhaseMny;
    }

    public void setProjectPhaseMny(BigDecimal projectPhaseMny) {
        this.projectPhaseMny = projectPhaseMny;
    }
    public BigDecimal getCorpProfitMny() {
        return corpProfitMny;
    }

    public void setCorpProfitMny(BigDecimal corpProfitMny) {
        this.corpProfitMny = corpProfitMny;
    }
    public BigDecimal getPayCorpProfitMny() {
        return payCorpProfitMny;
    }

    public void setPayCorpProfitMny(BigDecimal payCorpProfitMny) {
        this.payCorpProfitMny = payCorpProfitMny;
    }
    public BigDecimal getProjectCashMny() {
        return projectCashMny;
    }

    public void setProjectCashMny(BigDecimal projectCashMny) {
        this.projectCashMny = projectCashMny;
    }
    public BigDecimal getPayProjectCashMny() {
        return payProjectCashMny;
    }

    public void setPayProjectCashMny(BigDecimal payProjectCashMny) {
        this.payProjectCashMny = payProjectCashMny;
    }
    public BigDecimal getDeductionMny() {
        return deductionMny;
    }

    public void setDeductionMny(BigDecimal deductionMny) {
        this.deductionMny = deductionMny;
    }
    public BigDecimal getRiskDeductionMny() {
        return riskDeductionMny;
    }

    public void setRiskDeductionMny(BigDecimal riskDeductionMny) {
        this.riskDeductionMny = riskDeductionMny;
    }
    public BigDecimal getExamineCashMny() {
        return examineCashMny;
    }

    public void setExamineCashMny(BigDecimal examineCashMny) {
        this.examineCashMny = examineCashMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-riskmortgage-impl-3.0.0-20231205.095049-100-sources.jar: com/ejianc/business/cash/bean/CashEntity.java <==
package com.ejianc.business.cash.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 兑现计算表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_riskmortgage_cash")
public class CashEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_org_id")
    private Long projectOrgId; // 项目所属组织id
    @TableField(value="project_org_code")
    private String projectOrgCode; // 项目所属组织编码
    @TableField(value="project_org_name")
    private String projectOrgName; // 项目所属组织名称
    @TableField(value="employee_id")
    private Long employeeId; // 经办人id
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办人部门id
    @TableField(value="department_code")
    private String departmentCode; // 经办人部门编码
    @TableField(value="department_name")
    private String departmentName; // 经办人部门名称
    @TableField(value="node_stage")
    private String nodeStage; // 节点阶段
    @TableField(value="approve_cost_mny")
    private BigDecimal approveCostMny; // 审定造价
    @TableField(value="pay_engineering_mny")
    private BigDecimal payEngineeringMny; // 已收工程款
    @TableField(value="cost_mny")
    private BigDecimal costMny; // 已归集实际成本
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 应缴税金
    @TableField(value="pay_tax_mny")
    private BigDecimal payTaxMny; // 已交税金
    @TableField(value="management_mny")
    private BigDecimal managementMny; // 应交管理费
    @TableField(value="pay_management_mny")
    private BigDecimal payManagementMny; // 已缴管理费
    @TableField(value="project_phase_mny")
    private BigDecimal projectPhaseMny; // 项目盈亏金额
    @TableField(value="corp_profit_mny")
    private BigDecimal corpProfitMny; // 应交公司利润
    @TableField(value="pay_corp_profit_mny")
    private BigDecimal payCorpProfitMny; // 已缴公司利润
    @TableField(value="project_cash_mny")
    private BigDecimal projectCashMny; // 项目应兑现金额
    @TableField(value="pay_project_cash_mny")
    private BigDecimal payProjectCashMny; // 已预支兑现
    @TableField(value="deduction_mny")
    private BigDecimal deductionMny; // 未完成责任指标扣款
    @TableField(value="risk_deduction_mny")
    private BigDecimal riskDeductionMny; // 风险金抵扣
    @TableField(value="examine_cash_mny")
    private BigDecimal examineCashMny; // 考核兑现金额
    @TableField(value="memo")
    private String memo; // 备注

    @TableField(value="bill_code")
    private String billCode; // 单据编码

    @TableField(value="approve_flag")
    private Integer approveFlag; // 是否被兑现审批引用  1-引用  0-未引用

    public Integer getApproveFlag() {
        return approveFlag;
    }

    public void setApproveFlag(Integer approveFlag) {
        this.approveFlag = approveFlag;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getProjectOrgId() {
        return projectOrgId;
    }

    public void setProjectOrgId(Long projectOrgId) {
        this.projectOrgId = projectOrgId;
    }
    public String getProjectOrgCode() {
        return projectOrgCode;
    }

    public void setProjectOrgCode(String projectOrgCode) {
        this.projectOrgCode = projectOrgCode;
    }
    public String getProjectOrgName() {
        return projectOrgName;
    }

    public void setProjectOrgName(String projectOrgName) {
        this.projectOrgName = projectOrgName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getNodeStage() {
        return nodeStage;
    }

    public void setNodeStage(String nodeStage) {
        this.nodeStage = nodeStage;
    }
    public BigDecimal getApproveCostMny() {
        return approveCostMny;
    }

    public void setApproveCostMny(BigDecimal approveCostMny) {
        this.approveCostMny = approveCostMny;
    }
    public BigDecimal getPayEngineeringMny() {
        return payEngineeringMny;
    }

    public void setPayEngineeringMny(BigDecimal payEngineeringMny) {
        this.payEngineeringMny = payEngineeringMny;
    }
    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getPayTaxMny() {
        return payTaxMny;
    }

    public void setPayTaxMny(BigDecimal payTaxMny) {
        this.payTaxMny = payTaxMny;
    }
    public BigDecimal getManagementMny() {
        return managementMny;
    }

    public void setManagementMny(BigDecimal managementMny) {
        this.managementMny = managementMny;
    }
    public BigDecimal getPayManagementMny() {
        return payManagementMny;
    }

    public void setPayManagementMny(BigDecimal payManagementMny) {
        this.payManagementMny = payManagementMny;
    }
    public BigDecimal getProjectPhaseMny() {
        return projectPhaseMny;
    }

    public void setProjectPhaseMny(BigDecimal projectPhaseMny) {
        this.projectPhaseMny = projectPhaseMny;
    }
    public BigDecimal getCorpProfitMny() {
        return corpProfitMny;
    }

    public void setCorpProfitMny(BigDecimal corpProfitMny) {
        this.corpProfitMny = corpProfitMny;
    }
    public BigDecimal getPayCorpProfitMny() {
        return payCorpProfitMny;
    }

    public void setPayCorpProfitMny(BigDecimal payCorpProfitMny) {
        this.payCorpProfitMny = payCorpProfitMny;
    }
    public BigDecimal getProjectCashMny() {
        return projectCashMny;
    }

    public void setProjectCashMny(BigDecimal projectCashMny) {
        this.projectCashMny = projectCashMny;
    }
    public BigDecimal getPayProjectCashMny() {
        return payProjectCashMny;
    }

    public void setPayProjectCashMny(BigDecimal payProjectCashMny) {
        this.payProjectCashMny = payProjectCashMny;
    }
    public BigDecimal getDeductionMny() {
        return deductionMny;
    }

    public void setDeductionMny(BigDecimal deductionMny) {
        this.deductionMny = deductionMny;
    }
    public BigDecimal getRiskDeductionMny() {
        return riskDeductionMny;
    }

    public void setRiskDeductionMny(BigDecimal riskDeductionMny) {
        this.riskDeductionMny = riskDeductionMny;
    }
    public BigDecimal getExamineCashMny() {
        return examineCashMny;
    }

    public void setExamineCashMny(BigDecimal examineCashMny) {
        this.examineCashMny = examineCashMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
